ResetMessage

Struct ResetMessage 

pub struct ResetMessage {
    pub trip_group_1: Option<bool>,
    pub trip_group_2_proprietary: Option<bool>,
    pub service_component_identification: Option<u8>,
    pub engine_build_hours_reset: Option<bool>,
    pub steering_straight_ahead_position_reset: Option<bool>,
    pub engine_spark_plug_secondary_voltage_tracking_reset: Option<bool>,
    pub engine_ignition_control_maintenance_hours_reset: Option<bool>,
    pub bin_lift_count_reset: Option<bool>,
    pub tire_configuration_information: Option<bool>,
    pub tire_sensor_information: Option<bool>,
}

Fields

trip_group_1: Option<bool>

Command signal used to reset the PGNs and parameters as defined in Table SPN988_A.

trip_group_2_proprietary: Option<bool>

Command signal used to reset proprietary parameters associated with a trip but not defined within this document.

service_component_identification: Option<u8>

Identification of component needing service.

engine_build_hours_reset: Option<bool>

Command signal used to reset the engine rebuild hours.

steering_straight_ahead_position_reset: Option<bool>

Used to reset the straight ahead position for a steering sensor in the steering column or a steering controller’s straight ahead position on any steerable axle.

engine_spark_plug_secondary_voltage_tracking_reset: Option<bool>

Command signal used to reset the ignition controller average, maximum, and minimum level tracking of the spark plug secondary voltages and to reset the learned misfire rate.

engine_ignition_control_maintenance_hours_reset: Option<bool>

Used to reset the maintenance hour counter for an engine ignition control module.

bin_lift_count_reset: Option<bool>

Used to reset the bin lift count as reported in PGN 64594.

tire_configuration_information: Option<bool>

Command signal used to initiate change in the tire configuration of the vehicle system.

tire_sensor_information: Option<bool>

Command signal used to initiate change in the tire sensor identification information.

Implementations

Source

impl ResetMessage

pub fn from_pdu(pdu: &[u8]) -> Self

Panics

Panics if pdu has fewer than 8 bytes.

pub fn to_pdu(&self) -> [u8; 8]