pub struct InletExhaustConditions1Message {
pub particulate_trap_inlet_pressure: Option<u8>,
pub boost_pressure: Option<u8>,
pub intake_manifold_temperature: Option<i8>,
pub air_inlet_pressure: Option<u8>,
pub air_filter_differential_pressure: Option<u8>,
pub exhaust_gas_temperature: Option<i16>,
pub coolant_filter_differential_pressure: Option<u8>,
}Fields
particulate_trap_inlet_pressure: Option<u8>Exhaust back pressure as a result of particle accumulation on filter media placed in the exhaust stream.
boost_pressure: Option<u8>Gage pressure of air measured downstream on the compressor discharge side of the turbocharger. See also SPNs 1127-1130 for alternate range and resolution. If there is one boost pressure to report and this range and resolution is adequate, this parameter should be used.
intake_manifold_temperature: Option<i8>Temperature of pre-combustion air found in intake manifold of engine air supply system.
air_inlet_pressure: Option<u8>Absolute air pressure at inlet to intake manifold or air box.
air_filter_differential_pressure: Option<u8>Change in engine air system pressure, measured across the filter, due to the filter and any accumulation of solid foreign matter on or in the filter. This is the measurement of the first filter in a multiple air filter system. In a single air filter application, this is the only SPN used. Filter numbering follows the guidelines noted in section, Naming Convention For Engine Parameters.
exhaust_gas_temperature: Option<i16>Temperature of combustion byproducts leaving the engine. See SPNs 2433 and 2434 for engines with more than one exhause gas temperature measurement.
coolant_filter_differential_pressure: Option<u8>Change in coolant pressure, measured across the filter, due to the filter and any accumulation of solid or semisolid matter on or in the filter.
Implementations
Sourceimpl InletExhaustConditions1Message
impl InletExhaustConditions1Message
Sourcepub fn from_pdu(pdu: &[u8]) -> Self
pub fn from_pdu(pdu: &[u8]) -> Self
Panics
Panics if pdu has fewer than 7 bytes.
Examples found in repository?
17fn decode_data(pgn: PGN, data: &[u8]) {
18 println!("Data Decoded:");
19 match pgn {
20 PGN::TorqueSpeedControl1 => {
21 println!(" {}", TorqueSpeedControl1Message::from_pdu(data));
22 }
23 PGN::ElectronicEngineController1 => {
24 println!(" {}", ElectronicEngineController1Message::from_pdu(data));
25 }
26 PGN::ElectronicEngineController2 => {
27 println!(" {}", ElectronicEngineController2Message::from_pdu(data));
28 }
29 PGN::ElectronicEngineController3 => {
30 println!(" {}", ElectronicEngineController3Message::from_pdu(data));
31 }
32 PGN::ElectronicBrakeController1 => {
33 println!(" {}", ElectronicBrakeController1Message::from_pdu(data));
34 }
35 PGN::AmbientConditions => {
36 println!(" {}", AmbientConditionsMessage::from_pdu(data));
37 }
38 PGN::VehiclePosition => {
39 println!(" {}", VehiclePositionMessage::from_pdu(data));
40 }
41 PGN::FuelEconomy => {
42 println!(" {}", FuelEconomyMessage::from_pdu(data));
43 }
44 PGN::EngineFluidLevelPressure1 => {
45 println!(" {}", EngineFluidLevelPressure1Message::from_pdu(data));
46 }
47 PGN::FuelConsumption => {
48 println!(" {}", FuelConsumptionMessage::from_pdu(data));
49 }
50 PGN::VehicleDistance => {
51 println!(" {}", VehicleDistanceMessage::from_pdu(data));
52 }
53 PGN::HighResolutionVehicleDistance => {
54 println!(" {}", HighResolutionVehicleDistanceMessage::from_pdu(data));
55 }
56 PGN::FanDrive => {
57 println!(" {}", FanDriveMessage::from_pdu(data));
58 }
59 PGN::Shutdown => {
60 println!(" {}", ShutdownMessage::from_pdu(data));
61 }
62 PGN::EngineTemperature1 => {
63 println!(" {}", EngineTemperature1Message::from_pdu(data));
64 }
65 PGN::InletExhaustConditions1 => {
66 println!(" {}", InletExhaustConditions1Message::from_pdu(data));
67 }
68 PGN::VehicleElectricalPower1 => {
69 println!(" {}", VehicleElectricalPowerMessage::from_pdu(data));
70 }
71 PGN::EngineFluidLevelPressure2 => {
72 println!(" {}", EngineFluidLevelPressure2Message::from_pdu(data));
73 }
74 PGN::AuxiliaryInputOutputStatus => {
75 println!(" {}", CabIlluminationMessage::from_pdu(data));
76 }
77 PGN::ECUHistory => {
78 println!(" {}", ECUHistoryMessage::from_pdu(data));
79 }
80 PGN::TANKInformation1 => {
81 println!(" {}", TankInformation1Message::from_pdu(data));
82 }
83 PGN::Tachograph => {
84 println!(" {}", TachographMessage::from_pdu(data));
85 }
86 PGN::PowerTakeoffInformation => {
87 println!(" {}", PowerTakeoffInformationMessage::from_pdu(data));
88 }
89 PGN::DiagnosticMessage1 => {
90 println!(" {}", diagnostic::Message1::from_pdu(data));
91 }
92 PGN::Request => {
93 println!(" Request PGN: {:?}", protocol::request_from_pdu(data));
94 }
95 PGN::TimeDate => {
96 // TimeDate currently uses Debug formatting for its decoded representation,
97 // unlike other messages in this function that use Display. This is
98 // intentional because TimeDate does not provide a custom Display format.
99 println!(" {:?}", TimeDate::from_pdu(data));
100 }
101 _ => {
102 println!(" Unknown PGN for data decoding.");
103 }
104 }
105}